@@ -143,6 +143,7 @@ describe 'heat' do
     it 'sets default value for http_proxy_to_wsgi middleware' do
       is_expected.to contain_oslo__middleware('heat_config').with(
         :enable_proxy_headers_parsing => '<SERVICE DEFAULT>',
+        :max_request_body_size        => '<SERVICE DEFAULT>',
       )
     end
 
@@ -285,12 +286,12 @@ describe 'heat' do
   shared_examples_for 'with ec2authtoken auth uri set' do
     before do
       params.merge!(
-        :keystone_ec2_uri => 'http://1.2.3.4:5000/v2.0/ec2tokens'
+        :keystone_ec2_uri => 'http://1.2.3.4:5000/v3/ec2tokens'
       )
     end
 
     it do
-      is_expected.to contain_heat_config('ec2authtoken/auth_uri').with_value('http://1.2.3.4:5000/v2.0/ec2tokens')
+      is_expected.to contain_heat_config('ec2authtoken/auth_uri').with_value('http://1.2.3.4:5000/v3/ec2tokens')
     end
   end
 
